@@ -1,3 +1,5 @@
+from typing import Any
+
 from siteforms.tests.testapp.models import Thing, Another
 from siteforms.toolbox import ReadOnlyWidget
 
@@ -8,13 +10,19 @@ def test_basic(form):
 
         template_name = 'mywidget.html'
 
+    class MyMultipleWidget(ReadOnlyWidget):
+
+        def format_value_hook(self, value: Any):
+            return 'dumdum'
+
     form_cls = form(
         model=Thing,
-        readonly_fields={'fchar', 'fforeign', 'fchoices', 'fbool'},
-        fields=['fchar', 'ftext', 'fforeign', 'fchoices', 'fbool'],
+        readonly_fields={'fchar', 'fforeign', 'fchoices', 'fbool', 'fm2m'},
+        fields=['fchar', 'ftext', 'fforeign', 'fchoices', 'fbool', 'fm2m'],
         model_meta={
             'widgets': {
                 'ftext': MyWidget,
+                'fm2m': MyMultipleWidget,
             }
         },
     )
@@ -28,3 +36,4 @@ def test_basic(form):
     assert '&lt;unknown (q)&gt;</div>' in html  # Unknown in choices
     assert 'mywidgetdata' in html  # data from template
     assert 'id="id_fbool" disabled>No</div>' in html  # readonly bool
+    assert '>dumdum<' in html  # multiple widget
